import { __decorate, __metadata } from 'tslib';
import { CommonModule } from '@angular/common';
import { Input, Component, ChangeDetectionStrategy, Pipe, NgModule } from '@angular/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { MatIconModule, MatButtonModule } from '@angular/material';
import { MatTabsModule } from '@angular/material/tabs';
import { DocsExampleModule } from '@ngx-docs/example';
import { PrismModule } from '@ngx-prism/core';
import { DomSanitizer } from '@angular/platform-browser';

let ExamplePageShellComponent = class ExamplePageShellComponent {
    constructor() {
        this.exampleTitle = 'Example';
        this.exampleSources = {};
        this.otherSources = [];
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], ExamplePageShellComponent.prototype, "exampleTitle", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ExamplePageShellComponent.prototype, "exampleSources", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], ExamplePageShellComponent.prototype, "otherSources", void 0);
ExamplePageShellComponent = __decorate([
    Component({
        selector: 'app-example-page-shell',
        template: "<div\n    class=\"experimental-page\"\n    fxLayout.gt-md=\"row\"\n    fxLayout.lt-md=\"column\"\n    fxLayoutAlign=\"space-evenly stretch\"\n    fxLayoutAlign.lt-md=\"center\">\n    <div fxFlex.gt-sm=\"50\">\n        <ngx-docs-example\n            [title]=\"exampleTitle\"\n            [html]=\"exampleSources.html\"\n            [ts]=\"exampleSources.ts\"\n            [css]=\"exampleSources.css\">\n            <div class=\"body\">\n                <ng-content></ng-content>\n            </div>\n        </ngx-docs-example>\n    </div>\n    <source-tabs\n        title=\"Other files\"\n        [files]=\"otherSources\"\n        fxFlex.gt-sm=\"50\"></source-tabs>\n</div>\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [])
], ExamplePageShellComponent);

let SourceTabsComponent = class SourceTabsComponent {
};
__decorate([
    Input(),
    __metadata("design:type", String)
], SourceTabsComponent.prototype, "title", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], SourceTabsComponent.prototype, "files", void 0);
SourceTabsComponent = __decorate([
    Component({
        selector: 'source-tabs',
        template: "<div class=\"ngx-docs-example\">\n  <div\n      class=\"ngx-docs-example-title\"\n      fxLayout=\"row\"\n      fxLayoutAlign=\"space-between center\">\n      <span\n          class=\"title\"\n          fxHide.xs\n          fxShow.sm-xl>\n          {{title}}\n      </span>\n      <button mat-button>\n          <mat-icon></mat-icon>\n      </button>\n  </div>\n  <div class=\"ngx-docs-example-source\">\n      <mat-tab-group>\n          <mat-tab\n              [label]=\"file.name\"\n              *ngFor=\"let file of files\">\n              <ngx-prism\n                  [language]=\"file.language\"\n                  [code]=\"file.content\">\n              </ngx-prism>\n          </mat-tab>\n      </mat-tab-group>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], SourceTabsComponent);

const AppComponents = [
    ExamplePageShellComponent,
    SourceTabsComponent
];

let SafeHtmlPipe = class SafeHtmlPipe {
    constructor(_sanitizer) {
        this._sanitizer = _sanitizer;
    }
    transform(value, args) {
        if (this._sanitizer) {
            return this._sanitizer.bypassSecurityTrustHtml(value);
        }
        else {
            return value;
        }
    }
};
SafeHtmlPipe = __decorate([
    Pipe({ name: 'safeHtml' }),
    __metadata("design:paramtypes", [DomSanitizer])
], SafeHtmlPipe);

var TeamHivePackageCoreModule_1;
let TeamHivePackageCoreModule = TeamHivePackageCoreModule_1 = class TeamHivePackageCoreModule {
    static forRoot() {
        return {
            ngModule: TeamHivePackageCoreModule_1,
            providers: []
        };
    }
};
TeamHivePackageCoreModule = TeamHivePackageCoreModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            PrismModule,
            MatTabsModule,
            MatIconModule,
            MatButtonModule,
            FlexLayoutModule,
            DocsExampleModule.forRoot(),
        ],
        entryComponents: [
            SourceTabsComponent
        ],
        exports: [
            SourceTabsComponent,
            ExamplePageShellComponent,
            CommonModule,
            SafeHtmlPipe
        ],
        declarations: [
            SourceTabsComponent,
            ExamplePageShellComponent,
            SafeHtmlPipe
        ]
    })
], TeamHivePackageCoreModule);

/**
 * Generated bundle index. Do not edit.
 */

export { AppComponents, ExamplePageShellComponent, SafeHtmlPipe, SourceTabsComponent, TeamHivePackageCoreModule };
//# sourceMappingURL=teamhive-angular-package-core.js.map
